==> haskell-monad-par-0.3.6-119.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-par
version:              0.3.6
visibility:           public
id:                   monad-par-0.3.6-8xKxWU13ECf344gJwPJTMu
key:                  monad-par-0.3.6-8xKxWU13ECf344gJwPJTMu
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  0e4cea6f6932659f2b3ca46f64c2adb1
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-par-0.3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-par-0.3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-par-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par
hs-libraries:         HSmonad-par-0.3.6-8xKxWU13ECf344gJwPJTMu
depends:
    abstract-deque-0.3-HQwvQVbqXRwJKwfaFtRVtH
    abstract-par-0.3.3-1dic12KP6HG1xgohiLvlv6 array-0.5.6.0
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    monad-par-extras-0.3.3-Lo0LacZPPum6MnfInbJ63S mtl-2.3.1
    mwc-random-0.15.2.0-C3D8kiUTx4cAR7alE49l8B
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.6-120-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-par
version:              0.3.6
visibility:           public
id:                   monad-par-0.3.6-5oBDy7HqKI73HC0dYoRv8Q
key:                  monad-par-0.3.6-5oBDy7HqKI73HC0dYoRv8Q
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  88384f70aaefa347a2d1328dd5e34001
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-par-0.3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-par-0.3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-par-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par
hs-libraries:         HSmonad-par-0.3.6-5oBDy7HqKI73HC0dYoRv8Q
depends:
    abstract-deque-0.3-FO2L0As35bE4we1GdAp2tF
    abstract-par-0.3.3-1dic12KP6HG1xgohiLvlv6 array-0.5.6.0
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    monad-par-extras-0.3.3-Gn7JEqsnOJfBQYUOE0OTOI mtl-2.3.1
    mwc-random-0.15.2.0-DaAM0ROjU9kKbsqzvOqtbb
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
